clear all
close all
% Main driver program for basis calculations,
% including P-greedy point selection.
global RBFtype;  % type of RBF see frbf.m
global RBFpar;   % parameter of RBF, see frbf.m
global RBFscale; % scale of RBF, see frbf.m
global pausevalue
pausevalue=0
%
% RBFtype='g';  % basis function Gauss kernel
% RBFscale=1;   
% RBFpar=0;

%
RBFtype='tp';  % basis function tps
RBFscale=1;   
RBFpar=2; % 
polorder=2
%
% RBFtype='w'; % basis function Wendland kernel
% RBFscale=10;  % scale for Wendland must be larger  
% RBFpar=2; 
%
% -----------------------data sites-----------------------------
he=.03333;   % h for evaluation grid
[dsites, ind, xee, yee, xe, ye]=cutcircle(he); % generates points
Np=length(xee(ind)); % number of points for evaluation
polvalues=polynomials(dsites,polorder);
[npv, npd]=size(polvalues)
% we want to extract a unisolvent subset by QR with pivoting 
[Q,R,E] = qr(polvalues');
tn1=norm((polvalues')*E-Q*R) % just a check
% we have to reorder the points
polvalues=E'*polvalues;
ind=E'*ind;
dsites=E'*dsites;
tn2=norm(polvalues-polynomials(dsites,polorder)) % check
tn3=norm(polvalues'-Q*R) % check 
% now plot points
figure
plot(dsites(:,1),dsites(:,2),'.',dsites(1:npd,1),dsites(1:npd,2),'rx');
cp=condest(polvalues(1:npd,:)) % check unisolvency and condition there
% now get matrix for interpolation
intkermat=[kermat(dsites(1:npd,:),dsites(1:npd,:))  polvalues(1:npd,:);...
    polvalues(1:npd,:)' zeros(npd,npd)];
% matrix for evaluation
valmat=[kermat(dsites(1:npd,:),dsites); polvalues'];
sintmat=size(intkermat)
svalmat=size(valmat)
% We want the Lagrange basis in plottable form
uv=intkermat\valmat;
% The rows 
suv=size(uv)
return
for i=1:npd
figure
valfull=zeros(length(xe(:)),1);
valfull(ind)=uv(i,:);
z=zeros(size(xee));
z(ind)=uv(i,:);
surf(xe,ye, reshape(z,size(xe)))    
end
for i=1:npd
figure
valfull=zeros(length(xe(:)),1);
valfull(ind)=uv(i,:);
z=zeros(size(xee));
z(ind)=uv(npd+i,:);
surf(xe,ye, reshape(z,size(xe)))    
end
return


%
% Now the greedy Newton-based method for getting points
maxN=10;  % Maximal number of data sites used
Ptol=1.e-12; % tolerance for square (!) of power function
% Here is a PowerGreedy program.
% The power function is independent of the basis, so we can use the 
% greedy point selection program for the Newton basis:
[Lmatrix, UNew, mi] = GreedyPowerNewton (dsites, Ptol, maxN); %RS: see the comments there...
% RS: Note that mi might have less elements than maxN,
% in particular if the problem is ill--conditioned.
% The dsites(mi,:) are the selected points   
disp(sprintf('%d points selected',length(mi)))
nslength=length(dsites(:,1))
figure
plot(dsites(:,1),dsites(:,2),'y.',dsites(mi,1),dsites(mi,2),'ro');
title ('Points selected')
% Now we have the interpolation points, do all bases 


Ueig=eigenbasis(dsites, mi);
basismovie(Ueig,dsites, ind, mi, xe, ye, 'Eigen') 
close all
disp('Hit enter')
pause


ULag=Lagrangebasis(dsites, mi);
basismovie(ULag,dsites, ind, mi, xe, ye, 'Lagrange')
% LebLag=Lebesgueplot(ULag, ind, xe, ye, 'Lagrange')
close all
disp('Hit enter')
pause

UNew=Newtonbasis(dsites, mi);  % not needed, basis is already in UNew
basismovie(UNew,dsites, ind, mi, xe, ye, 'Newton')
% LebNew=Lebesgueplot(UNew, ind, xe, ye, 'Newton')
close all
disp('Hit enter')
pause


Usvd=SVDbasis(dsites, mi);
basismovie(Usvd,dsites, ind, mi, xe, ye, 'SVD') 
% LebSVD=Lebesgueplot(Usvd, ind, xe, ye, 'SVD')
close all
disp('Hit enter')
pause

Uqr=QRbasis(dsites, mi);
basismovie(Uqr,dsites, ind, mi, xe, ye, 'QR') 
close all
disp('Hit enter')
pause

Ulq=LQbasis(dsites, mi);
basismovie(Ulq,dsites, ind, mi, xe, ye, 'LQ') 
close all
disp('Hit enter')
pause


fullmovie(UNew, Usvd, Ueig, ULag, Uqr, Ulq, dsites, ind, mi, xe, ye, 'All')

return
